@@ -1,4 +1,6 @@
-# -*- coding: utf-8 -*-
+# emacs: -*- mode: python; coding: utf-8; py-indent-offset: 4; indent-tabs-mode: t -*-
+# vi: set ft=python sts=4 ts=4 sw=4 noet :
+
 # This file is part of Fail2Ban.
 #
 # Fail2Ban is free software; you can redistribute it and/or modify
@@ -13,15 +15,15 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Fail2Ban; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 # Author: Cyril Jaquier
 # 
-# $Revision: 729 $
+# $Revision$
 
 __author__ = "Cyril Jaquier"
-__version__ = "$Revision: 729 $"
-__date__ = "$Date: 2009-02-08 20:50:44 +0100 (Sun, 08 Feb 2009) $"
+__version__ = "$Revision$"
+__date__ = "$Date$"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
@@ -30,6 +32,10 @@ import re, time
 from mytime import MyTime
 import iso8601
 
+import logging
+logSys = logging.getLogger("fail2ban.datetemplate")
+
+
 class DateTemplate:
 	
 	def __init__(self):
@@ -76,7 +82,7 @@ class DateEpoch(DateTemplate):
 		dateMatch = self.matchDate(line)
 		if dateMatch:
 			# extract part of format which represents seconds since epoch
-			date = list(time.localtime(float(dateMatch.group())))
+			date = list(MyTime.localtime(float(dateMatch.group())))
 		return date
 
 
@@ -86,20 +92,20 @@ class DateEpoch(DateTemplate):
 # standard.
 
 class DateStrptime(DateTemplate):
-	
+
 	TABLE = dict()
-	TABLE["Jan"] = []
-	TABLE["Feb"] = [u"Fév"]
-	TABLE["Mar"] = [u"Mär"]
-	TABLE["Apr"] = ["Avr"]
-	TABLE["May"] = ["Mai"]
-	TABLE["Jun"] = []
-	TABLE["Jul"] = []
-	TABLE["Aug"] = ["Aou"]
-	TABLE["Sep"] = []
-	TABLE["Oct"] = ["Okt"]
-	TABLE["Nov"] = []
-	TABLE["Dec"] = [u"Déc", "Dez"]
+	TABLE["Jan"] = ["Sty"]
+	TABLE["Feb"] = [u"Fév", "Lut"]
+	TABLE["Mar"] = [u"Mär", "Mar"]
+	TABLE["Apr"] = ["Avr", "Kwi"]
+	TABLE["May"] = ["Mai", "Maj"]
+	TABLE["Jun"] = ["Lip"]
+	TABLE["Jul"] = ["Sie"]
+	TABLE["Aug"] = ["Aou", "Wrz"]
+	TABLE["Sep"] = ["Sie"]
+	TABLE["Oct"] = [u"Paź"]
+	TABLE["Nov"] = ["Lis"]
+	TABLE["Dec"] = [u"Déc", "Dez", "Gru"]
 	
 	def __init__(self):
 		DateTemplate.__init__(self)
@@ -116,6 +122,8 @@ class DateStrptime(DateTemplate):
 		for t in DateStrptime.TABLE:
 			for m in DateStrptime.TABLE[t]:
 				if date.find(m) >= 0:
+					logSys.debug(u"Replacing %r with %r in %r" %
+								 (m, t, date))
 					return date.replace(m, t)
 		return date
 	convertLocale = staticmethod(convertLocale)
@@ -132,12 +140,22 @@ class DateStrptime(DateTemplate):
 				conv = self.convertLocale(dateMatch.group())
 				try:
 					date = list(time.strptime(conv, self.getPattern()))
-				except ValueError, e:
+				except (ValueError, re.error), e:
 					# Try to add the current year to the pattern. Should fix
 					# the "Feb 29" issue.
-					conv += " %s" % MyTime.gmtime()[0]
-					pattern = "%s %%Y" % self.getPattern()
-					date = list(time.strptime(conv, pattern))
+					opattern = self.getPattern()
+					# makes sense only if %Y is not in already:
+					if not '%Y' in opattern:
+						pattern = "%s %%Y" % opattern
+						conv += " %s" % MyTime.gmtime()[0]
+						date = list(time.strptime(conv, pattern))
+					else:
+						# we are helpless here
+						raise ValueError(
+							"Given pattern %r does not match. Original "
+							"exception was %r and Feb 29 workaround could not "
+							"be tested due to already present year mark in the "
+							"pattern" % (opattern, e))
 			if date[0] < 2000:
 				# There is probably no year field in the logs
 				date[0] = MyTime.gmtime()[0]
@@ -145,6 +163,9 @@ class DateStrptime(DateTemplate):
 				# If the date is greater than the current time, we suppose
 				# that the log is not from this year but from the year before
 				if time.mktime(date) > MyTime.time():
+					logSys.debug(
+						u"Correcting deduced year from %d to %d since %f > %f" %
+						(date[0], date[0]-1, time.mktime(date), MyTime.time()))
 					date[0] -= 1
 				elif date[1] == 1 and date[2] == 1:
 					# If it is Jan 1st, it is either really Jan 1st or there
@@ -169,7 +190,7 @@ class DateTai64n(DateTemplate):
 			value = dateMatch.group()
 			seconds_since_epoch = value[2:17]
 			# convert seconds from HEX into local time stamp
-			date = list(time.localtime(int(seconds_since_epoch, 16)))
+			date = list(MyTime.localtime(int(seconds_since_epoch, 16)))
 		return date
 
 
