@@ -1,3 +1,6 @@
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: t -*-
+# vi: set ft=python sts=4 ts=4 sw=4 noet :
+
 # This file is part of Fail2Ban.
 #
 # Fail2Ban is free software; you can redistribute it and/or modify
@@ -12,16 +15,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Fail2Ban; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-# Author: Cyril Jaquier
-# 
-# $Revision: 696 $
+# Author: Cyril Jaquier, Yaroslav Halchenko
 
-__author__ = "Cyril Jaquier"
-__version__ = "$Revision: 696 $"
-__date__ = "$Date: 2008-05-19 23:05:32 +0200 (Mon, 19 May 2008) $"
-__copyright__ = "Copyright (c) 2004 Cyril Jaquier"
+__author__ = "Cyril Jaquier, Yaroslav Halchenko"
+__copyright__ = "Copyright (c) 2004 Cyril Jaquier, 2012 Yaroslav Halchenko"
 __license__ = "GPL"
 
 from failmanager import FailManagerEmpty
@@ -47,7 +46,7 @@ class FilterGamin(FileFilter):
 	#
 	# Initialize the filter object with default values.
 	# @param jail the jail object
-	
+
 	def __init__(self, jail):
 		FileFilter.__init__(self, jail)
 		self.__modified = False
@@ -60,36 +59,43 @@ class FilterGamin(FileFilter):
 		logSys.debug("Got event: " + `event` + " for " + path)
 		if event in (gamin.GAMCreated, gamin.GAMChanged, gamin.GAMExists):
 			logSys.debug("File changed: " + path)
-			self.getFailures(path)
 			self.__modified = True
 
+		self._process_file(path)
+
+
+	def _process_file(self, path):
+		"""Process a given file
+
+		TODO -- RF:
+		this is a common logic and must be shared/provided by FileFilter
+		"""
+		self.getFailures(path)
+		try:
+			while True:
+				ticket = self.failManager.toBan()
+				self.jail.putFailTicket(ticket)
+		except FailManagerEmpty:
+			self.failManager.cleanup(MyTime.time())
+		self.dateDetector.sortTemplate()
+		self.__modified = False
 
 	##
 	# Add a log file path
 	#
 	# @param path log file path
 
-	def addLogPath(self, path, tail = False):
-		if self.containsLogPath(path):
-			logSys.error(path + " already exists")
-		else:
-			self.monitor.watch_file(path, self.callback)
-			FileFilter.addLogPath(self, path, tail)
-			logSys.info("Added logfile = %s" % path)			
-	
+	def _addLogPath(self, path):
+		self.monitor.watch_file(path, self.callback)
+
 	##
 	# Delete a log path
 	#
 	# @param path the log file to delete
-	
-	def delLogPath(self, path):
-		if not self.containsLogPath(path):
-			logSys.error(path + " is not monitored")
-		else:
-			self.monitor.stop_watch(path)
-			FileFilter.delLogPath(self, path)
-			logSys.info("Removed logfile = %s" % path)
-		
+
+	def _delLogPath(self, path):
+		self.monitor.stop_watch(path)
+
 	##
 	# Main loop.
 	#
@@ -99,30 +105,22 @@ class FilterGamin(FileFilter):
 
 	def run(self):
 		self.setActive(True)
+		# Gamin needs a loop to collect and dispatch events
 		while self._isActive():
 			if not self.getIdle():
 				# We cannot block here because we want to be able to
 				# exit.
 				if self.monitor.event_pending():
 					self.monitor.handle_events()
-
-				if self.__modified:
-					try:
-						while True:
-							ticket = self.failManager.toBan()
-							self.jail.putFailTicket(ticket)
-					except FailManagerEmpty:
-						self.failManager.cleanup(MyTime.time())
-					self.dateDetector.sortTemplate()
-					self.__modified = False
-				time.sleep(self.getSleepTime())
-			else:
-				time.sleep(self.getSleepTime())
-		# Cleanup Gamin
-		self.__cleanup()
+			time.sleep(self.getSleepTime())
 		logSys.debug(self.jail.getName() + ": filter terminated")
 		return True
 
+
+	def stop(self):
+		super(FilterGamin, self).stop()
+		self.__cleanup()
+
 	##
 	# Desallocates the resources used by Gamin.
 
