@@ -1,3 +1,6 @@
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: t -*-
+# vi: set ft=python sts=4 ts=4 sw=4 noet :
+
 # This file is part of Fail2Ban.
 #
 # Fail2Ban is free software; you can redistribute it and/or modify
@@ -12,15 +15,15 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Fail2Ban; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 # Author: Cyril Jaquier
 # 
-# $Revision: 638 $
+# $Revision$
 
 __author__ = "Cyril Jaquier"
-__version__ = "$Revision: 638 $"
-__date__ = "$Date: 2007-12-17 21:00:36 +0100 (Mon, 17 Dec 2007) $"
+__version__ = "$Revision$"
+__date__ = "$Date$"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
@@ -31,12 +34,25 @@ logSys = logging.getLogger("fail2ban")
 
 class Ticket:
 	
-	def __init__(self, ip, time):
+	def __init__(self, ip, time, matches=None):
+		"""Ticket constructor
+
+		@param ip the IP address
+		@param time the ban time
+		@param matches (log) lines caused the ticket
+		"""
+
 		self.__ip = ip
 		self.__time = time
 		self.__attempt = 0
 		self.__file = None
+		self.__matches = matches or []
+
+	def __str__(self):
+		return "%s: ip=%s time=%s #attempts=%d" % \
+			   (self.__class__, self.__ip, self.__time, self.__attempt)
 	
+
 	def setIP(self, value):
 		self.__ip = value
 	
@@ -61,11 +77,12 @@ class Ticket:
 	def getAttempt(self):
 		return self.__attempt
 
+	def getMatches(self):
+		return self.__matches
+
 
 class FailTicket(Ticket):
-	
-	def __init__(self, ip, time):
-		Ticket.__init__(self, ip, time)
+	pass
 
 
 ##
@@ -74,14 +91,4 @@ class FailTicket(Ticket):
 # This class extends the Ticket class. It is mainly used by the BanManager.
 
 class BanTicket(Ticket):
-	
-	##
-	# Constructor.
-	#
-	# Call the Ticket (parent) constructor and initialize default
-	# values.
-	# @param ip the IP address
-	# @param time the ban time
-	
-	def __init__(self, ip, time):
-		Ticket.__init__(self, ip, time)
+	pass
